@@ -18,9 +18,7 @@
 */
 #include "avibase.h"
 #include "avifmt.h"
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif
+#include "misc/fileio.h"
 
 
 /******************************************************************************
@@ -35,7 +33,7 @@ AviFrame *avi_get_frame_open(AviEdit *avi_edit)
 {
 	AviFrame *avi_frame;
 
-	if (avi_edit==NULL || avi_type(avi_edit)!=streamtypeVIDEO)
+	if (avi_edit == NULL || avi_type (avi_edit) != AVI_STREAM_VIDEO)
 		return NULL;
 	avi_frame=g_malloc(sizeof(AviFrame));
 	avi_frame->handler=0;
@@ -77,7 +75,7 @@ static BitmapInfoHeader *avi_get_frame_real(AviFrame *avi_frame,const gint pos)
 	if (pos<0 || avi_length(avi_edit)<=pos)
 		return NULL;				/* ϰϳ */
 	avi_get_file(avi_edit,pos);		/* AVIե */
-	if (avi_edit->file->handler==comptypeDIB) {
+	if (avi_edit->file->handler == AVI_STREAM_COMP_DIB) {
 		/* ̥ե졼Υå */
 		for (i=pos-avi_edit->offset+avi_edit->file->start;i>0;i--)
 			if (avi_edit->file->index[i].size>0)
@@ -89,15 +87,16 @@ static BitmapInfoHeader *avi_get_frame_real(AviFrame *avi_frame,const gint pos)
 		bmih=g_malloc(size+avi_edit->file->index[i].size);
 		/* إå */
 		g_memmove(bmih,avi_edit->file->bmih,size);
-		if (bmih_get_compression(bmih)==comptypeDIB)
-			bmih_set_compression(bmih,BI_RGB);
+		if (bmih_get_compression (bmih) == AVI_STREAM_COMP_DIB)
+			bmih_set_compression (bmih, BI_COMP_RGB);
 		if (bmih_get_size_image(bmih)<=0)
 			bmih_set_size_image(bmih,bm_image_bytes(bmih));
 		/* ᡼ */
 		if (avi_edit->file->data==NULL) {
 			/* ե */
-			lseek(avi_edit->file->fd,avi_edit->file->index[i].offset,SEEK_SET);
-			read(avi_edit->file->fd,(guint8 *)bmih+size,
+			fileio_seek (avi_edit->file->fio, avi_edit->file->index[i].offset,
+															FILEIO_SEEK_SET);
+			fileio_read (avi_edit->file->fio, (guint8 *)bmih + size,
 												avi_edit->file->index[i].size);
 		} else {
 			/*  */
@@ -132,8 +131,8 @@ static BitmapInfoHeader *avi_get_frame_real(AviFrame *avi_frame,const gint pos)
 		i=j=pos-avi_edit->offset+avi_edit->file->start;
 		if (avi_frame->pos!=pos-1 || pos<=avi_edit->offset)
 			while (j>0) {	/* Ϣ³ƤʤȤ */
-				if ((avi_edit->file->index[j].flags&AVIIF_KEYFRAME)!=0
-											&& avi_edit->file->index[j].size>0)
+				if ((avi_edit->file->index[j].flags & AVI_IF_KEYFRAME) != 0
+										&& avi_edit->file->index[j].size > 0)
 					break;
 				j--;
 			}
@@ -152,9 +151,9 @@ static BitmapInfoHeader *avi_get_frame_real(AviFrame *avi_frame,const gint pos)
 				input=g_realloc(input,avi_edit->file->index[j].size);
 				if (avi_edit->file->data==NULL) {
 					/* ե */
-					lseek(avi_edit->file->fd,
-									avi_edit->file->index[j].offset,SEEK_SET);
-					read(avi_edit->file->fd,input,
+					fileio_seek (avi_edit->file->fio,
+							avi_edit->file->index[j].offset, FILEIO_SEEK_SET);
+					fileio_read (avi_edit->file->fio, input,
 												avi_edit->file->index[j].size);
 				} else {
 					/*  */
@@ -163,9 +162,9 @@ static BitmapInfoHeader *avi_get_frame_real(AviFrame *avi_frame,const gint pos)
 												avi_edit->file->index[j].size);
 				}
 				icm_decompress(avi_frame->icm_object,
-							(avi_edit->file->index[j].flags&AVIIF_KEYFRAME)==0
-												?ICM_DECOMPRESS_NOTKEYFRAME:0,
-																input,output);
+						(avi_edit->file->index[j].flags & AVI_IF_KEYFRAME) == 0
+											? ICM_DECOMPRESS_NOTKEYFRAME : 0,
+																input, output);
 			}
 			j++;
 		}
@@ -221,15 +220,16 @@ BitmapInfoHeader *avi_get_frame(AviFrame *avi_frame,const gint pos,
 					|| bmih_get_bit_count(bmih0)!=bit_count || bit_count<16) {
 		/* 32ӥåȤѴ */
 		if (bmih_get_bit_count(bmih0)!=32) {
-			bmih1=g_malloc(bx_all_bytes(bmih_get_width(bmih0),
-										bmih_get_height(bmih0),32,BI_RGB,0));
+			bmih1 = g_malloc(bx_all_bytes (bmih_get_width (bmih0),
+								bmih_get_height (bmih0), 32, BI_COMP_RGB, 0));
 			bitmap_convert_32(bmih0,bmih1);
 			g_free(bmih0);
 			bmih0=bmih1;
 		}
 		/* Ѵ */
 		if (bmih_get_width(bmih0)!=width || bmih_get_height(bmih0)!=height) {
-			bmih1=g_malloc(bx_all_bytes(width,height,32,BI_RGB,0));
+			bmih1 = g_malloc (bx_all_bytes
+										(width, height, 32, BI_COMP_RGB, 0));
 			bmih_set_width(bmih1,width);
 			bmih_set_height(bmih1,height);
 			bitmap_zoom_32(bmih0,bmih1);
@@ -238,7 +238,8 @@ BitmapInfoHeader *avi_get_frame(AviFrame *avi_frame,const gint pos,
 		}
 		/* Ѵ */
 		if (bit_count!=32) {
-			bmih1=g_malloc(bx_all_bytes(width,height,bit_count,BI_RGB,0));
+			bmih1 = g_malloc (bx_all_bytes
+								(width, height, bit_count, BI_COMP_RGB, 0));
 			bmih_set_color_used(bmih1,0);
 			bmih_set_color_important(bmih1,0);
 			switch (bit_count) {
@@ -281,8 +282,9 @@ BitmapInfoHeader *avi_get_frame(AviFrame *avi_frame,const gint pos,
 	    width,
 	   height,⤵
 	      RET,RAWؤΥݥ,NULL:顼								*/
-guchar *avi_get_frame32(AviFrame *avi_frame,const gint pos,
-											const gint width,const gint height)
+guint8 *
+avi_get_frame32 (AviFrame *avi_frame, const gint pos,
+										const gint width, const gint height)
 {
 	gint i,n,xx,yy,src,dst;
 	guchar *p;
@@ -340,12 +342,12 @@ guchar *avi_get_frame32(AviFrame *avi_frame,const gint pos,
 	     RET,TRUE:ե졼,FALSE:󥭡ե졼							*/
 gboolean avi_is_keyframe(AviEdit *avi_edit,const gint pos)
 {
-	if (avi_edit!=NULL && avi_type(avi_edit)==streamtypeVIDEO) {
+	if (avi_edit != NULL && avi_type (avi_edit) == AVI_STREAM_VIDEO) {
 		/* ӥǥ */
 		avi_get_file(avi_edit,pos);/* AVIե */
 		return (avi_edit->file->index
-							[pos-avi_edit->offset+avi_edit->file->start].flags
-														&AVIIF_KEYFRAME)!=0;
+						[pos-avi_edit->offset + avi_edit->file->start].flags
+														&AVI_IF_KEYFRAME) != 0;
 	}
 	return TRUE;
 }
