@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1999-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1999-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,13 +25,18 @@
 #define __BITMAP_H__
 
 
-#include <glib.h>
+#include "common.h"
 
 
-#define BI_RGB			0
-#define BI_RLE8			1
-#define BI_RLE4			2
-#define BI_BITFIELDS	3
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+#define BI_COMP_RGB			0
+#define BI_COMP_RLE8		1
+#define BI_COMP_RLE4		2
+#define BI_COMP_BITFIELDS	3
 
 
 #define BMFH_SIZE 14
@@ -188,7 +193,7 @@ typedef struct { guint8 dummy[RGBQUAD_SIZE]; } RgbQuad;
 	 color_used,
 	        RET,Хȿ													*/
 #define bx_color_bytes(width,height,bit_count,compression,color_used)		\
-			((compression)!=BI_BITFIELDS									\
+			((compression)!=BI_COMP_BITFIELDS								\
 			?bx_color_used(width,height,bit_count,compression,color_used)	\
 											*RGBQUAD_SIZE:sizeof(guint32)*3)
 
@@ -436,4 +441,7 @@ void bitmap_overlay_32(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1,
 								gint x_overlay,gint y_overlay,gboolean trans);
 
 
+#ifdef __cplusplus
+}
+#endif
 #endif
