@@ -19,6 +19,7 @@
 #include "icm.h"
 #include "avifmt.h"
 #include <gdk/gdkkeysyms.h>
+#include "misc/fileio.h"
 #include "misc/misc.h"
 #include "misc/profile.h"
 #if defined(W32CODECDIR) || defined(USE_CODEC)
@@ -217,7 +218,7 @@ gboolean icm_init(void)
 #endif /* defined(USE_CODEC) */
 							g_free(value);
 						}
-						fpath = misc_get_full_path(path);
+						fpath = fileio_get_full_path (path);
 						g_free(path);
 						if ((path = g_hash_table_lookup(ghash, (gconstpointer)handler)))
 							g_free(path);
@@ -799,7 +800,7 @@ gsize icm_compress(IcmObject *icm_object,
 		icm_object->frame++;
 		g_memmove(icm_object->prev,input,icm_object->prev_size);
 		if (key_frame!=NULL)
-			*key_frame=(dwFlags&AVIIF_KEYFRAME)!=0;
+			*key_frame = (dwFlags & AVI_IF_KEYFRAME) != 0;
 		return bmih_get_size_image(icm_object->bmih_out);
 	}
 #endif
