@@ -85,20 +85,24 @@ void signal_activate_menu_window(GtkWidget *widget,GtkWidget *child)
 
 void signal_activate_menu_history(GtkWidget *widget,gchar *file)
 {
-#ifndef USE_GTK2
+#if defined USE_THREAD && ! defined USE_GTK2
 	pthread_t id;
-#endif
+#endif /* USE_THREAD and not USE_GTK2 */
 	FileOpen *file_open;
 
 	file_open=g_malloc(sizeof(FileOpen));
 	file_open->file=g_strdup(file);
 	file_open->merge=file_merge;
-#ifdef USE_GTK2
+#ifdef USE_THREAD
+# ifdef USE_GTK2
 	g_thread_create((GThreadFunc)file_open_edit,file_open,TRUE,NULL);
-#else
+# else /* not USE_GTK2 */
 	pthread_create(&id,NULL,(void *)file_open_edit,file_open);
 	pthread_detach(id);
-#endif
+# endif /* not USE_GTK2 */
+#else /* not USE_THREAD */
+	file_open_edit (file_open);
+#endif /* not USE_THREAD */
 }
 
 
@@ -225,11 +229,11 @@ void signal_drag_data_received(GtkWidget *widget,GdkDragContext *context,
 	gchar **files;
 	gint i;
 	FileOpen *file_open;
-#ifdef USE_GTK2
+#if defined USE_GTK2
 	gchar *file;
-#else /* not USE_GTK2 */
+#elif defined USE_THREAD
 	pthread_t id;
-#endif /* not USE_GTK2 */
+#endif /* USE_THREAD and not USE_GTK2 */
 
 	files = g_strsplit (selection_data->data, "\r\n", G_MAXINT);
 	for (i = 0; files[i] != NULL; i++)
@@ -248,13 +252,17 @@ void signal_drag_data_received(GtkWidget *widget,GdkDragContext *context,
 			file_open->file = g_strdup (files[i] + 5);
 #endif /* not USE_GTK2 */
 			file_open->merge = file_merge;
-#ifdef USE_GTK2
+#ifdef USE_THREAD
+# ifdef USE_GTK2
 			g_thread_create ((GThreadFunc)file_open_edit,
 														file_open, TRUE, NULL);
-#else /* not USE_GTK2 */
+# else /* not USE_GTK2 */
 			pthread_create (&id, NULL, (void *)file_open_edit, file_open);
 			pthread_detach (id);
-#endif /* not USE_GTK2 */
+# endif /* not USE_GTK2 */
+#else /* not USE_THREAD */
+			file_open_edit (file_open);
+#endif /* not USE_THREAD */
 		  }
 	  }
 	g_strfreev (files);
@@ -306,9 +314,9 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 	gboolean result=TRUE,paste[2],*arg_files;
 	gchar **argv;
 	gint i,count,max,sx;
-#ifndef USE_GTK2
+#if defined USE_THREAD && ! defined USE_GTK2
 	pthread_t id;
-#endif
+#endif /* USE_THREAD and not USE_GTK2 */
 	AviEdit **avi_edit;
 	FileOpen *file_open;
 	GdkAtom *atoms;
@@ -368,7 +376,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 				paste[0]=paste[1]=FALSE;
 				for (i=0;avi_edit[i]!=NULL;i++)
 					switch (avi_type(avi_edit[i])) {
-						case streamtypeVIDEO:
+						case AVI_STREAM_VIDEO:
 							if (paste[0]) {
 								avi_release(avi_edit[i]);
 							} else {
@@ -384,17 +392,25 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 								paste[0]=TRUE;
 							}
 							break;
-						case streamtypeAUDIO:
+						case AVI_STREAM_AUDIO:
 							if (paste[1]) {
 								avi_release(avi_edit[i]);
 							} else {
 								if (vmaid->avi_edit[1]==NULL) {
 									vmaid->avi_edit[1]=avi_edit[i];
 								} else if (!avi_paste(vmaid->avi_edit[1],
+#ifdef G_HAVE_GINT64
 									MIN(avi_time_to_sample(vmaid->avi_edit[1],
 											(gint64)vmaid->cursor.frame*1000
 													*vmaid->scale/vmaid->rate),
 										avi_length(vmaid->avi_edit[0])),
+#else /* not G_HAVE_GINT64 */
+									MIN (avi_time_to_sample
+														(vmaid->avi_edit[1],
+												vmaid->cursor.frame * 1000
+												* vmaid->scale / vmaid->rate),
+										avi_length (vmaid->avi_edit[0])),
+#endif /* not G_HAVE_GINT64 */
 																avi_edit[i])) {
 									avi_release(avi_edit[i]);
 									result=FALSE;
@@ -463,13 +479,17 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 				file_open=g_malloc(sizeof(FileOpen));
 				file_open->file=g_strdup(argv[i]);
 				file_open->merge=file_merge;
-#ifdef USE_GTK2
+#ifdef USE_THREAD
+# ifdef USE_GTK2
 				g_thread_create((GThreadFunc)file_open_edit,
 														file_open,TRUE,NULL);
-#else
+# else /* not USE_GTK2 */
 				pthread_create(&id,NULL,(void *)file_open_edit,file_open);
 				pthread_detach(id);
-#endif
+# endif /* not USE_GTK2 */
+#else /* not USE_THREAD */
+				file_open_edit (file_open);
+#endif /* not USE_THREAD */
 			}
 		g_free(arg_files);
 		g_strfreev(argv);
@@ -485,9 +505,9 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 gboolean signal_delete(GtkWidget *widget,GdkEvent *event,gpointer user_data)
 {
 	gint page;
-#ifndef USE_GTK2
+#if defined USE_THREAD && ! defined USE_GTK2
 	pthread_t id;
-#endif
+#endif /* USE_THREAD and not USE_GTK2 */
 	VmaidWindow *vmaid;
 
 	while ((page=gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))>=0) {
@@ -497,12 +517,16 @@ gboolean signal_delete(GtkWidget *widget,GdkEvent *event,gpointer user_data)
 			return TRUE;
 		gtk_notebook_remove_page(GTK_NOTEBOOK(notebook),page);
 	}
-#ifdef USE_GTK2
+#ifdef USE_THREAD
+# ifdef USE_GTK2
 	g_thread_create((GThreadFunc)close_program,NULL,TRUE,NULL);
-#else
+# else /* not USE_GTK2 */
 	pthread_create(&id,NULL,(void *)close_program,NULL);
 	pthread_detach(id);
-#endif
+# endif /* not USE_GTK2 */
+#else /* not USE_THREAD */
+	close_program ();
+#endif /* not USE_THREAD */
 	return TRUE;
 }
 
