@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -261,12 +261,12 @@ gboolean size_dialog(SizeDialog *size)
 	}
 
 	/* ե졼ȥܥå */
-	vbox=gtk_vbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	vbox = gtk_vbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
 	gtk_box_pack_start(GTK_BOX(vbox),table,FALSE,FALSE,0);
 
-	hbox0=gtk_hbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(hbox0),8);
+	hbox0 = gtk_hbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox0), SPACING);
 	hbox1=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),label0,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spin0,TRUE,TRUE,0);
@@ -280,7 +280,7 @@ gboolean size_dialog(SizeDialog *size)
 	if (check!=NULL)
 		gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);
 
-	hbox0=gtk_hbox_new(FALSE,8);
+	hbox0 = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_end(GTK_BOX(hbox0),button9,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox0),button8,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
