@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,9 +20,15 @@
 #define __THREAD_H__
 
 
-#include <bits/sigset.h>
-#include <pthread.h>
 #include "vmaid.h"
+#if defined USE_THREAD && ! defined USE_GTK2
+# ifdef HAVE_BITS_SIGSET_H
+#   include <bits/sigset.h>
+# endif /* HAVE_BITS_SIGSET_H */
+# ifdef HAVE_PTHREAD_H
+#   include <pthread.h>
+# endif /* HAVE_PTHREAD_H */
+#endif /* USE_THREAD and not USE_GTK2 */
 
 
 #define THREAD_MODE_EXIT 0
@@ -30,13 +36,25 @@
 #define THREAD_MODE_SAVE 2
 #define THREAD_MODE_FRAME 3
 #define THREAD_MODE_REVERSE 4
+#ifndef USE_THREAD
+# define THREAD_ID_STANDARD 0
+# define THREAD_ID_CLOSE 1
+#endif /* not USE_THREAD */
 
 
 typedef struct ThreadList_Tag {
 	gboolean userbreak;	/* TRUE:³,FALSE:׵ */
 	gint mode;			/* 0:λ,1:,2:¸,3:ե졼,4:ȿž */
 	gint percent;		/* ʹԾ(0...100) */
+#ifdef USE_THREAD
+# ifdef USE_GTK2
+	GThread *id;
+# else /* not USE_GTK2 */
 	pthread_t id;
+# endif /* not USE_GTK2 */
+#else /* not USE_THREAD */
+	gint id;
+#endif /* not USE_THREAD */
 } ThreadList;
 
 
@@ -50,30 +68,65 @@ typedef struct ThreadList_Tag {
 	mode,⡼(0:λ,1:,2:¸,3:ե졼,4:ȿž)
 	file,ե̾
 	 RET,TRUE:ｪλ,FALSE:顼											*/
-gboolean thread_insert(pthread_t id,const gint mode,const gchar *file);
+#ifdef USE_THREAD
+# ifdef USE_GTK2
+gboolean
+thread_insert (GThread *id, const gint mode, const gchar *file);
+# else /* not USE_GTK2 */
+gboolean
+thread_insert (pthread_t id, const gint mode, const gchar *file);
+# endif /* not USE_GTK2 */
+#else /* not USE_THREAD */
+gboolean
+thread_insert (gint id, const gint mode, const gchar *file);
+#endif /* not USE_THREAD */
+
+
+/*	ꥹȤ
+	 id,åID
+	RET,TRUE:ｪλ,FALSE:顼											*/
+#ifdef USE_THREAD
+# ifdef USE_GTK2
+gboolean
+thread_delete (GThread *id);
+# else /* not USE_GTK2 */
+gboolean
+thread_delete (pthread_t id);
+# endif /* not USE_GTK2 */
+#else /* not USE_THREAD */
+gboolean
+thread_delete(gint id);
+#endif /* not USE_THREAD */
 
 
 /*	ꥹȤ򹹿
 	     id,åID
 	percent,ʹԾ
 	    RET,TRUE:³,FALSE:											*/
-gboolean thread_idling(pthread_t id,const gint percent);
+#ifdef USE_THREAD
+# ifdef USE_GTK2
+gboolean
+thread_idling (GThread *id, const gint percent);
+# else /* not USE_GTK2 */
+gboolean
+thread_idling (pthread_t id, const gint percent);
+# endif /* not USE_GTK2 */
+#else /* not USE_THREAD */
+gboolean
+thread_idling (gint id, const gint percent);
+#endif /* not USE_THREAD */
 
 
-/*	ꥹȤ
-	 id,åID
-	RET,TRUE:ｪλ,FALSE:顼											*/
-gboolean thread_delete(pthread_t id);
-
-
-/*	ꥹȤ
+/*	åɤߤ
 	all,TRUE:٤ƤΥå,FALSE:򤵤줿åɤΤ
 	RET,TRUE:ｪλ,FALSE:顼											*/
-gboolean thread_break(const gboolean all);
+gboolean
+thread_break (const gboolean all);
 
 
 /*	ץνλ(Ωå)											*/
-void *close_program(void);
+void *
+close_program (void);
 
 
 #endif
